//
//  NickCenter.h
//  NickCenter
//
//  Created by Mobeleader on 12/01/14.
//  Copyright (c) 2014 Beleader Internet Marketing  S.L. All rights reserved.
//

//To enable this library you need to add the "-ObjC -all_load" flag in the "Build Settings" under "Other Linker Flags"

//To enable Location manager since iOS 8 you need to add in your Info.plist file this key "NSLocationWhenInUseUsageDescription" with this description "Location is required to find out where you are"

#import <UIKit/UIKit.h>
#import <Foundation/Foundation.h>
#import "NCUser.h"

@protocol NickCenterProtocol <NSObject>
@optional

//Optional function to show the errors
//The error variable contains the explanation of the error
-(void)onError:(NSString *)error;

//Optional function to show Warnings
//The warning variable contains the explanation of the warnings
-(void)onWarning:(NSString *)warning;

//Optional function to implement something when NickCenter is Active for this app on the server
-(void)onActive;

//Optional function to implement something when NickCenter is Inactive for this app on the server
-(void)onInactive;

//Optional function to implement something when user is Registered
//The user variable contains the user data
-(void)onRegisterPerformed:(NCUser *) user dictionary:(NSMutableDictionary *) userDictionary;

//Optional function to implement something when user is Logged
//The user variable contains the user data
-(void)onLoginPerformed:(NCUser *) user dictionary:(NSMutableDictionary *) userDictionary;

//Optional function to implement something when Session is closed
-(void)onSessionClosed;

//Optional function to implement something when Register View is opened
-(void)onRegisterViewOpened;

//Optional function to implement something when Register button is clicked on Register View
-(void)onRegisterRegisterButtonClicked;

//Optional function to implement something when Login button is clicked on Register View
-(void)onRegisterLoginButtonClicked;

//Optional function to implement something when Close button is clicked on Register View
-(void)onRegisterCloseButtonClicked;

//Optional function to implement something when Login View is opened
-(void)onLoginViewOpened;

//Optional function to implement something when login button is clicked on Login View
-(void)onLoginLoginButtonClicked;

//Optional function to implement something when Rescue button is clicked on Login View
-(void)onLoginRescueButtonClicked;

//Optional function to implement something when Close button is clicked on Login View
-(void)onLoginCloseButtonClicked;

//Optional function to implement something when Register button is clicked on Login View
-(void)onLoginRegisterButtonClicked;

//Optional function to implement something when Rescue View is opened
-(void)onRescueViewOpened;

//Optional function to implement something when Rescue button is clicked on Rescue View
-(void)onRescueRescueButtonClicked;

//Optional function to implement something when Close button is clicked on Rescue View
-(void)onRescueCloseButtonClicked;

//Optional function to implement something when NickCenter is finished
-(void)onFinished;

@end


@interface NickCenter : NSObject

//Requiered value created in mobeleader website.
@property (nonatomic, retain) NSString *appHash;

//Optional value
@property(nonatomic,strong) UIViewController *rootViewController;

//Optional value for delegate NickCenter.
@property (retain) id delegate;

//Optional values for customice views.
@property(nonatomic,retain) UIColor *viewsBackgroundColor;
@property(nonatomic,retain) UIImage *viewsBackgroundImage;
@property(nonatomic,retain) UIColor *headerBackgroundColor;
@property(nonatomic,retain) UIImage *headerBackgroundImage;
@property(nonatomic,retain) UIColor *headerBottomLineColor;
@property(nonatomic,retain) UIColor *headerTextColor;
@property(nonatomic,retain) UIFont *headerFont;
@property(nonatomic,retain) UIColor *textFieldsBackgroundColor;
@property(nonatomic,retain) UIColor *textFieldsPlaceholderColor;
@property(nonatomic,retain) UIColor *textFieldsTextColor;
@property(nonatomic,retain) UIFont *textFieldsFont;
@property(nonatomic,retain) UIColor *buttonsNormalBackgroundColor;
@property(nonatomic,retain) UIColor *buttonsHighlightedBackgroundColor;
@property(nonatomic,retain) UIColor *buttonsNormalTextColor;
@property(nonatomic,retain) UIColor *buttonsHighlightedTextColor;
@property(nonatomic,retain) UIColor *buttonsBorderColor;
@property(nonatomic,retain) UIFont *buttonsFont;
@property(nonatomic,retain) UIColor* termsFontColor;
@property(nonatomic,retain) UIColor* termsSwitchActiveColor;
@property(nonatomic,retain) UIColor* termsSwitchInactiveColor;

//Optional value for preloading user data in register.
@property (nonatomic, retain) NSString *userName;
@property (nonatomic, retain) NSString *userSurname;
@property (nonatomic, retain) NSString *userEmail;
@property (nonatomic, retain) NSString *userPhone;
@property (nonatomic, retain) NSString *userNick;
@property (nonatomic, retain) NSString *userGender;
@property (nonatomic, retain) NSString *userBirthDate;



//Function to start NickCenter
- (void)checkAndLaunch;

//Functio to close Session of NickCenter
-(void)closeSession;


@end
